import os
import pathlib

from inflex import Noun
from sqlitedict import SqliteDict

path = pathlib.Path(__file__).parent.resolve()


def get_record(word: str) -> dict:
    with SqliteDict(os.path.join(path, 'data/en_thesaurus.sqlite')) as db:
        if word in db:
            return db[word]
    return {}


def get_syns(word: str) -> dict:
    """Get synonyms for a word from the thesaurus."""
    word = word.lower()
    record = get_record(word)
    if record == {}:
        # Check if word is plural and if so, get synonyms for singular form
        if Noun(word).is_plural():
            word = Noun(word).singular()
            record = get_record(word)
            if record != {}:
                if 'noun' in record:
                    # Convert noun synonyms to plural forms
                    record['noun'] = [Noun(s).plural() for s in record['noun'] if Noun(s).is_singular()]
                    return record
    return record


import unittest
from synnamon import get_syns


class TestGetSyns(unittest.TestCase):
    def test_get_syns_pos(self):
        # Test case for a word that exists in the thesaurus
        result = get_syns('jump')
        self.assertIn('noun', result)
        self.assertIn('verb', result)

    def test_get_syns_not_exist(self):
        # Test case for a word that does not exist in the thesaurus
        result = get_syns('notaword')
        self.assertEqual(result, {})

    def test_get_syns_plural(self):
        # Test case for a plural noun that does not exists in the thesaurus
        result = get_syns('dragons')
        self.assertIn('noun', result)
        self.assertListEqual(result['noun'], ['flying lizards',
                                                'tartars',
                                                'Dragons',
                                                'Dracos',
                                                'firedrakes',
                                                'flying dragons'])
        

if __name__ == '__main__':
    unittest.main()